teahaz API client
===================================================

### implemented/planned methods
**internal**
* [x] \_request
* [x] \_register

**basics**
* [x] login
* [x] get_messages(since)
* [x] get_file
* [x] send_message
* [x] send_file
* [x] create_invite
* [x] use_invite
* [x] create_chatroom
* [x] get_by_id
* [x] message_delete

**utility**
* [x] add_new_server
* [x] set_chatroom

**events**
* [x] on_message

**future**
* [ ] on_download(percentage/status)
